@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -31,7 +30,6 @@ from keystone.tests.unit import fakeldap
 from keystone.tests.unit.ksfixtures import database
 from keystone.tests.unit.ksfixtures import ldapdb
 
-
 CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
@@ -135,7 +133,7 @@ class DnCompareTest(unit.BaseTestCase):
 
     def test_dn_equal_unicode(self):
         # is_dn_equal can accept unicode
-        dn = u'cn=fäké,ou=OpenStack'
+        dn = 'cn=fäké,ou=OpenStack'
         self.assertTrue(common_ldap.is_dn_equal(dn, dn))
 
     def test_dn_diff_length(self):
@@ -199,29 +197,30 @@ class DnCompareTest(unit.BaseTestCase):
 
     def test_startswith_unicode(self):
         # dn_startswith accepts unicode.
-        child = u'cn=fäké,ou=OpenStäck'
-        parent = u'ou=OpenStäck'
+        child = 'cn=fäké,ou=OpenStäck'
+        parent = 'ou=OpenStäck'
         self.assertTrue(common_ldap.dn_startswith(child, parent))
 
 
 class LDAPDeleteTreeTest(unit.TestCase):
 
     def setUp(self):
-        super(LDAPDeleteTreeTest, self).setUp()
+        super().setUp()
 
         self.useFixture(
-            ldapdb.LDAPDatabase(dbclass=fakeldap.FakeLdapNoSubtreeDelete))
+            ldapdb.LDAPDatabase(dbclass=fakeldap.FakeLdapNoSubtreeDelete)
+        )
         self.useFixture(database.Database())
 
         self.load_backends()
         self.load_fixtures(default_fixtures)
 
     def config_overrides(self):
-        super(LDAPDeleteTreeTest, self).config_overrides()
+        super().config_overrides()
         self.config_fixture.config(group='identity', driver='ldap')
 
     def config_files(self):
-        config_files = super(LDAPDeleteTreeTest, self).config_files()
+        config_files = super().config_files()
         config_files.append(unit.dirs.tests_conf('backend_ldap.conf'))
         return config_files
 
@@ -247,13 +246,14 @@ class MultiURLTests(unit.TestCase):
 
     @mock.patch.object(common_ldap.KeystoneLDAPHandler, 'simple_bind_s')
     def test_multiple_urls_with_comma_randomized(self, mock_ldap_bind):
-        urls = ('ldap://localhost1,ldap://localhost2,'
-                'ldap://localhost3,ldap://localhost4,'
-                'ldap://localhost5,ldap://localhost6,'
-                'ldap://localhost7,ldap://localhost8,'
-                'ldap://localhost9,ldap://localhost0')
-        self.config_fixture.config(group='ldap', url=urls,
-                                   randomize_urls=True)
+        urls = (
+            'ldap://localhost1,ldap://localhost2,'
+            'ldap://localhost3,ldap://localhost4,'
+            'ldap://localhost5,ldap://localhost6,'
+            'ldap://localhost7,ldap://localhost8,'
+            'ldap://localhost9,ldap://localhost0'
+        )
+        self.config_fixture.config(group='ldap', url=urls, randomize_urls=True)
         base_ldap = common_ldap.BaseLdap(CONF)
         ldap_connection = base_ldap.get_connection()
 
@@ -261,16 +261,21 @@ class MultiURLTests(unit.TestCase):
         self.assertEqual(len(urls.split(',')), 10)
 
         # Check that the list is split into the same number of URIs
-        self.assertEqual(len(urls.split(',')),
-                         len(ldap_connection.conn.conn_pool.uri.split(',')))
+        self.assertEqual(
+            len(urls.split(',')),
+            len(ldap_connection.conn.conn_pool.uri.split(',')),
+        )
 
         # Check that the list is randomized
-        self.assertNotEqual(urls.split(','),
-                            ldap_connection.conn.conn_pool.uri.split(','))
+        self.assertNotEqual(
+            urls.split(','), ldap_connection.conn.conn_pool.uri.split(',')
+        )
 
         # Check that the list contains the same URIs
-        self.assertEqual(set(urls.split(',')),
-                         set(ldap_connection.conn.conn_pool.uri.split(',')))
+        self.assertEqual(
+            set(urls.split(',')),
+            set(ldap_connection.conn.conn_pool.uri.split(',')),
+        )
 
 
 class LDAPConnectionTimeoutTest(unit.TestCase):
@@ -280,14 +285,17 @@ class LDAPConnectionTimeoutTest(unit.TestCase):
     def test_connectivity_timeout_no_conn_pool(self, mock_ldap_bind):
         url = 'ldap://localhost'
         conn_timeout = 1  # 1 second
-        self.config_fixture.config(group='ldap',
-                                   url=url,
-                                   connection_timeout=conn_timeout,
-                                   use_pool=False)
+        self.config_fixture.config(
+            group='ldap',
+            url=url,
+            connection_timeout=conn_timeout,
+            use_pool=False,
+        )
         base_ldap = common_ldap.BaseLdap(CONF)
         ldap_connection = base_ldap.get_connection()
-        self.assertIsInstance(ldap_connection.conn,
-                              common_ldap.PythonLDAPHandler)
+        self.assertIsInstance(
+            ldap_connection.conn, common_ldap.PythonLDAPHandler
+        )
 
         # Ensure that the Network Timeout option is set.
         # Also ensure that the URL is set.
@@ -297,23 +305,27 @@ class LDAPConnectionTimeoutTest(unit.TestCase):
         # integration testing. If the LDAP option is set properly,
         # and we get back a valid connection URI then that should
         # suffice for this unit test.
-        self.assertEqual(conn_timeout,
-                         ldap.get_option(ldap.OPT_NETWORK_TIMEOUT))
+        self.assertEqual(
+            conn_timeout, ldap.get_option(ldap.OPT_NETWORK_TIMEOUT)
+        )
         self.assertEqual(url, ldap_connection.conn.conn._uri)
 
     @mock.patch.object(common_ldap.KeystoneLDAPHandler, 'simple_bind_s')
     def test_connectivity_timeout_with_conn_pool(self, mock_ldap_bind):
         url = 'ldap://localhost'
         conn_timeout = 1  # 1 second
-        self.config_fixture.config(group='ldap',
-                                   url=url,
-                                   pool_connection_timeout=conn_timeout,
-                                   use_pool=True,
-                                   pool_retry_max=1)
+        self.config_fixture.config(
+            group='ldap',
+            url=url,
+            pool_connection_timeout=conn_timeout,
+            use_pool=True,
+            pool_retry_max=1,
+        )
         base_ldap = common_ldap.BaseLdap(CONF)
         ldap_connection = base_ldap.get_connection()
-        self.assertIsInstance(ldap_connection.conn,
-                              common_ldap.PooledLDAPHandler)
+        self.assertIsInstance(
+            ldap_connection.conn, common_ldap.PooledLDAPHandler
+        )
 
         # Ensure that the Network Timeout option is set.
         # Also ensure that the URL is set.
@@ -323,8 +335,9 @@ class LDAPConnectionTimeoutTest(unit.TestCase):
         # integration testing. If the LDAP option is set properly,
         # and we get back a valid connection URI then that should
         # suffice for this unit test.
-        self.assertEqual(conn_timeout,
-                         ldap.get_option(ldap.OPT_NETWORK_TIMEOUT))
+        self.assertEqual(
+            conn_timeout, ldap.get_option(ldap.OPT_NETWORK_TIMEOUT)
+        )
         self.assertEqual(url, ldap_connection.conn.conn_pool.uri)
 
 
@@ -332,7 +345,7 @@ class SslTlsTest(unit.BaseTestCase):
     """Test for the SSL/TLS functionality in keystone.common.ldap.core."""
 
     def setUp(self):
-        super(SslTlsTest, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(config_fixture.Config(CONF))
 
     @mock.patch.object(common_ldap.KeystoneLDAPHandler, 'simple_bind_s')
@@ -347,10 +360,12 @@ class SslTlsTest(unit.BaseTestCase):
         (handle, certfile) = tempfile.mkstemp()
         self.addCleanup(os.unlink, certfile)
         self.addCleanup(os.close, handle)
-        self.config_fixture.config(group='ldap',
-                                   url='ldap://localhost',
-                                   use_tls=True,
-                                   tls_cacertfile=certfile)
+        self.config_fixture.config(
+            group='ldap',
+            url='ldap://localhost',
+            use_tls=True,
+            tls_cacertfile=certfile,
+        )
 
         self._init_ldap_connection(CONF)
 
@@ -360,10 +375,12 @@ class SslTlsTest(unit.BaseTestCase):
     def test_certdir_trust_tls(self):
         # We need this to actually exist, so we create a tempdir.
         certdir = self.useFixture(fixtures.TempDir()).path
-        self.config_fixture.config(group='ldap',
-                                   url='ldap://localhost',
-                                   use_tls=True,
-                                   tls_cacertdir=certdir)
+        self.config_fixture.config(
+            group='ldap',
+            url='ldap://localhost',
+            use_tls=True,
+            tls_cacertdir=certdir,
+        )
 
         self._init_ldap_connection(CONF)
 
@@ -375,10 +392,12 @@ class SslTlsTest(unit.BaseTestCase):
         (handle, certfile) = tempfile.mkstemp()
         self.addCleanup(os.unlink, certfile)
         self.addCleanup(os.close, handle)
-        self.config_fixture.config(group='ldap',
-                                   url='ldaps://localhost',
-                                   use_tls=False,
-                                   tls_cacertfile=certfile)
+        self.config_fixture.config(
+            group='ldap',
+            url='ldaps://localhost',
+            use_tls=False,
+            tls_cacertfile=certfile,
+        )
 
         self._init_ldap_connection(CONF)
 
@@ -388,10 +407,12 @@ class SslTlsTest(unit.BaseTestCase):
     def test_certdir_trust_ldaps(self):
         # We need this to actually exist, so we create a tempdir.
         certdir = self.useFixture(fixtures.TempDir()).path
-        self.config_fixture.config(group='ldap',
-                                   url='ldaps://localhost',
-                                   use_tls=False,
-                                   tls_cacertdir=certdir)
+        self.config_fixture.config(
+            group='ldap',
+            url='ldaps://localhost',
+            use_tls=False,
+            tls_cacertdir=certdir,
+        )
 
         self._init_ldap_connection(CONF)
 
@@ -403,7 +424,7 @@ class LDAPPagedResultsTest(unit.TestCase):
     """Test the paged results functionality in keystone.common.ldap.core."""
 
     def setUp(self):
-        super(LDAPPagedResultsTest, self).setUp()
+        super().setUp()
 
         self.useFixture(ldapdb.LDAPDatabase())
         self.useFixture(database.Database())
@@ -412,11 +433,11 @@ class LDAPPagedResultsTest(unit.TestCase):
         self.load_fixtures(default_fixtures)
 
     def config_overrides(self):
-        super(LDAPPagedResultsTest, self).config_overrides()
+        super().config_overrides()
         self.config_fixture.config(group='identity', driver='ldap')
 
     def config_files(self):
-        config_files = super(LDAPPagedResultsTest, self).config_files()
+        config_files = super().config_files()
         config_files.append(unit.dirs.tests_conf('backend_ldap.conf'))
         return config_files
 
@@ -425,18 +446,18 @@ class LDAPPagedResultsTest(unit.TestCase):
     def test_paged_results_control_api(self, mock_result3, mock_search_ext):
         mock_result3.return_value = ('', [], 1, [])
 
-        self.config_fixture.config(group='ldap',
-                                   page_size=1)
+        self.config_fixture.config(group='ldap', page_size=1)
 
         conn = PROVIDERS.identity_api.user.get_connection()
-        conn._paged_search_s('dc=example,dc=test',
-                             ldap.SCOPE_SUBTREE,
-                             'objectclass=*',
-                             ['mail', 'userPassword'])
+        conn._paged_search_s(
+            'dc=example,dc=test',
+            ldap.SCOPE_SUBTREE,
+            'objectclass=*',
+            ['mail', 'userPassword'],
+        )
         # verify search_ext() args - attrlist is tricky due to ordering
         args, _ = mock_search_ext.call_args
-        self.assertEqual(
-            ('dc=example,dc=test', 2, 'objectclass=*'), args[0:3])
+        self.assertEqual(('dc=example,dc=test', 2, 'objectclass=*'), args[0:3])
         attrlist = sorted([attr for attr in args[3] if attr])
         self.assertEqual(['mail', 'userPassword'], attrlist)
 
@@ -445,22 +466,24 @@ class CommonLdapTestCase(unit.BaseTestCase):
     """These test cases call functions in keystone.common.ldap."""
 
     def test_binary_attribute_values(self):
-        result = [(
-            'cn=junk,dc=example,dc=com',
-            {
-                'cn': ['junk'],
-                'sn': [uuid.uuid4().hex],
-                'mail': [uuid.uuid4().hex],
-                'binary_attr': [b'\x00\xFF\x00\xFF']
-            }
-        ), ]
+        result = [
+            (
+                'cn=junk,dc=example,dc=com',
+                {
+                    'cn': ['junk'],
+                    'sn': [uuid.uuid4().hex],
+                    'mail': [uuid.uuid4().hex],
+                    'binary_attr': [b'\x00\xFF\x00\xFF'],
+                },
+            ),
+        ]
         py_result = common_ldap.convert_ldap_result(result)
         # The attribute containing the binary value should
         # not be present in the converted result.
         self.assertNotIn('binary_attr', py_result[0][1])
 
     def test_utf8_conversion(self):
-        value_unicode = u'fäké1'
+        value_unicode = 'fäké1'
         value_utf8 = value_unicode.encode('utf-8')
 
         result_utf8 = common_ldap.utf8_encode(value_unicode)
@@ -475,22 +498,19 @@ class CommonLdapTestCase(unit.BaseTestCase):
         result_unicode = common_ldap.utf8_decode(value_unicode)
         self.assertEqual(value_unicode, result_unicode)
 
-        self.assertRaises(TypeError,
-                          common_ldap.utf8_encode,
-                          100)
+        self.assertRaises(TypeError, common_ldap.utf8_encode, 100)
 
         result_unicode = common_ldap.utf8_decode(100)
-        self.assertEqual(u'100', result_unicode)
+        self.assertEqual('100', result_unicode)
 
     def test_user_id_begins_with_0(self):
         user_id = '0123456'
-        result = [(
-            'cn=dummy,dc=example,dc=com',
-            {
-                'user_id': [user_id],
-                'enabled': ['TRUE']
-            }
-        ), ]
+        result = [
+            (
+                'cn=dummy,dc=example,dc=com',
+                {'user_id': [user_id], 'enabled': ['TRUE']},
+            ),
+        ]
         py_result = common_ldap.convert_ldap_result(result)
         # The user id should be 0123456, and the enabled
         # flag should be True
@@ -501,13 +521,12 @@ class CommonLdapTestCase(unit.BaseTestCase):
         user_id = '0123456'
         bitmask = '225'
         expected_bitmask = 225
-        result = [(
-            'cn=dummy,dc=example,dc=com',
-            {
-                'user_id': [user_id],
-                'enabled': [bitmask]
-            }
-        ), ]
+        result = [
+            (
+                'cn=dummy,dc=example,dc=com',
+                {'user_id': [user_id], 'enabled': [bitmask]},
+            ),
+        ]
         py_result = common_ldap.convert_ldap_result(result)
         # The user id should be 0123456, and the enabled
         # flag should be 225
@@ -518,13 +537,12 @@ class CommonLdapTestCase(unit.BaseTestCase):
         user_id = '0123456'
         bitmask = '0225'
         expected_bitmask = 225
-        result = [(
-            'cn=dummy,dc=example,dc=com',
-            {
-                'user_id': [user_id],
-                'enabled': [bitmask]
-            }
-        ), ]
+        result = [
+            (
+                'cn=dummy,dc=example,dc=com',
+                {'user_id': [user_id], 'enabled': [bitmask]},
+            ),
+        ]
         py_result = common_ldap.convert_ldap_result(result)
         # The user id should be 0123456, and the enabled
         # flag should be 225, the 0 is dropped.
@@ -532,31 +550,42 @@ class CommonLdapTestCase(unit.BaseTestCase):
         self.assertEqual(user_id, py_result[0][1]['user_id'][0])
 
     def test_user_id_and_user_name_with_boolean_string(self):
-        boolean_strings = ['TRUE', 'FALSE', 'true', 'false', 'True', 'False',
-                           'TrUe' 'FaLse']
+        boolean_strings = [
+            'TRUE',
+            'FALSE',
+            'true',
+            'false',
+            'True',
+            'False',
+            'TrUe',
+            'FaLse',
+        ]
         for user_name in boolean_strings:
             user_id = uuid.uuid4().hex
-            result = [(
-                'cn=dummy,dc=example,dc=com',
-                {
-                    'user_id': [user_id],
-                    'user_name': [user_name]
-                }
-            ), ]
+            result = [
+                (
+                    'cn=dummy,dc=example,dc=com',
+                    {'user_id': [user_id], 'user_name': [user_name]},
+                ),
+            ]
             py_result = common_ldap.convert_ldap_result(result)
             # The user name should still be a string value.
             self.assertEqual(user_name, py_result[0][1]['user_name'][0])
 
     def test_user_id_attribute_is_uuid_in_byte_form(self):
-        results = [(
-            'cn=alice,dc=example,dc=com',
-            {
-                'cn': [b'cn=alice'],
-                'objectGUID': [b'\xdd\xd8Rt\xee]bA\x8e(\xe39\x0b\xe1\xf8\xe8'],
-                'email': [uuid.uuid4().hex],
-                'sn': [uuid.uuid4().hex]
-            }
-        )]
+        results = [
+            (
+                'cn=alice,dc=example,dc=com',
+                {
+                    'cn': [b'cn=alice'],
+                    'objectGUID': [
+                        b'\xdd\xd8Rt\xee]bA\x8e(\xe39\x0b\xe1\xf8\xe8'
+                    ],
+                    'email': [uuid.uuid4().hex],
+                    'sn': [uuid.uuid4().hex],
+                },
+            )
+        ]
         py_result = common_ldap.convert_ldap_result(results)
         exp_object_guid = '7452d8dd-5dee-4162-8e28-e3390be1f8e8'
         self.assertEqual(exp_object_guid, py_result[0][1]['objectGUID'][0])
@@ -566,7 +595,7 @@ class LDAPFilterQueryCompositionTest(unit.BaseTestCase):
     """These test cases test LDAP filter generation."""
 
     def setUp(self):
-        super(LDAPFilterQueryCompositionTest, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(config_fixture.Config(CONF))
 
         self.base_ldap = common_ldap.BaseLdap(self.config_fixture.conf)
@@ -583,8 +612,9 @@ class LDAPFilterQueryCompositionTest(unit.BaseTestCase):
         # NOTE: doesn't have to be a real query, we just need to make sure the
         # same string is returned if there are no hints.
         query = uuid.uuid4().hex
-        self.assertEqual(query,
-                         self.base_ldap.filter_query(hints=hints, query=query))
+        self.assertEqual(
+            query, self.base_ldap.filter_query(hints=hints, query=query)
+        )
 
         # make sure the default query is an empty string
         self.assertEqual('', self.base_ldap.filter_query(hints=hints))
@@ -592,14 +622,19 @@ class LDAPFilterQueryCompositionTest(unit.BaseTestCase):
     def test_filter_with_empty_query_and_hints_set(self):
         hints = driver_hints.Hints()
         username = uuid.uuid4().hex
-        hints.add_filter(name=self.attribute_name,
-                         value=username,
-                         comparator='equals',
-                         case_sensitive=False)
-        expected_ldap_filter = '(&(%s=%s))' % (
-            self.filter_attribute_name, username)
-        self.assertEqual(expected_ldap_filter,
-                         self.base_ldap.filter_query(hints=hints))
+        hints.add_filter(
+            name=self.attribute_name,
+            value=username,
+            comparator='equals',
+            case_sensitive=False,
+        )
+        expected_ldap_filter = '(&({}={}))'.format(
+            self.filter_attribute_name,
+            username,
+        )
+        self.assertEqual(
+            expected_ldap_filter, self.base_ldap.filter_query(hints=hints)
+        )
 
     def test_filter_with_both_query_and_hints_set(self):
         hints = driver_hints.Hints()
@@ -608,31 +643,42 @@ class LDAPFilterQueryCompositionTest(unit.BaseTestCase):
         query = uuid.uuid4().hex
         username = uuid.uuid4().hex
         expected_result = '(&%(query)s(%(user_name_attr)s=%(username)s))' % (
-            {'query': query,
-             'user_name_attr': self.filter_attribute_name,
-             'username': username})
+            {
+                'query': query,
+                'user_name_attr': self.filter_attribute_name,
+                'username': username,
+            }
+        )
         hints.add_filter(self.attribute_name, username)
-        self.assertEqual(expected_result,
-                         self.base_ldap.filter_query(hints=hints, query=query))
+        self.assertEqual(
+            expected_result,
+            self.base_ldap.filter_query(hints=hints, query=query),
+        )
 
     def test_filter_with_hints_and_query_is_none(self):
         hints = driver_hints.Hints()
         username = uuid.uuid4().hex
-        hints.add_filter(name=self.attribute_name,
-                         value=username,
-                         comparator='equals',
-                         case_sensitive=False)
-        expected_ldap_filter = '(&(%s=%s))' % (
-            self.filter_attribute_name, username)
-        self.assertEqual(expected_ldap_filter,
-                         self.base_ldap.filter_query(hints=hints, query=None))
+        hints.add_filter(
+            name=self.attribute_name,
+            value=username,
+            comparator='equals',
+            case_sensitive=False,
+        )
+        expected_ldap_filter = '(&({}={}))'.format(
+            self.filter_attribute_name,
+            username,
+        )
+        self.assertEqual(
+            expected_ldap_filter,
+            self.base_ldap.filter_query(hints=hints, query=None),
+        )
 
 
 class LDAPSizeLimitTest(unit.TestCase):
     """Test the size limit exceeded handling in keystone.common.ldap.core."""
 
     def setUp(self):
-        super(LDAPSizeLimitTest, self).setUp()
+        super().setUp()
 
         self.useFixture(ldapdb.LDAPDatabase())
         self.useFixture(database.Database())
@@ -641,11 +687,11 @@ class LDAPSizeLimitTest(unit.TestCase):
         self.load_fixtures(default_fixtures)
 
     def config_overrides(self):
-        super(LDAPSizeLimitTest, self).config_overrides()
+        super().config_overrides()
         self.config_fixture.config(group='identity', driver='ldap')
 
     def config_files(self):
-        config_files = super(LDAPSizeLimitTest, self).config_files()
+        config_files = super().config_files()
         config_files.append(unit.dirs.tests_conf('backend_ldap.conf'))
         return config_files
 
@@ -653,7 +699,9 @@ class LDAPSizeLimitTest(unit.TestCase):
     def test_search_s_sizelimit_exceeded(self, mock_search_s):
         mock_search_s.side_effect = ldap.SIZELIMIT_EXCEEDED
         conn = PROVIDERS.identity_api.user.get_connection()
-        self.assertRaises(ks_exception.LDAPSizeLimitExceeded,
-                          conn.search_s,
-                          'dc=example,dc=test',
-                          ldap.SCOPE_SUBTREE)
+        self.assertRaises(
+            ks_exception.LDAPSizeLimitExceeded,
+            conn.search_s,
+            'dc=example,dc=test',
+            ldap.SCOPE_SUBTREE,
+        )
